//--------------------------------------------------------------------------
// File and Version Information:
//
// Description:
//	Class UserExample. This is a simple example of a user module. It
//      prints out each entrypoint (operation) as it is accessed and prints
//      some LRID bank information in the event entry.
//
// Environment:
//	Software developed for the BaBar Detector at the SLAC B-Factory.
//      Modified for CDF use by LSK
//
// Author List:
//
// Copyright Information:
//
//------------------------------------------------------------------------

//------------------------
// String Header First  --
//------------------------
#include <string>

//-----------------------
// This Class's Header --
//-----------------------
#include "Exercise/MinMod.hh"
//-------------
// C Headers --
//-------------
#include <assert.h>
#include <time.h>
//---------------
// C++ Headers --
//---------------
#include <iostream.h>

//-------------------------------
// Collaborating Class Headers --
//-------------------------------
#ifdef USE_CDFEDM2
#include "Edm/ConstHandle.hh"
#include "StorableBanks/LRID_StorableBank.hh"
#else
#include "Banks/LRID_Bank.hh"
#include "Trybos/TRY_Record_Iter_Same.hh"
#endif
#include "AbsEnv/AbsEnv.hh"
//-----------------------------------------------------------------------
// Local Macros, Typedefs, Structures, Unions and Forward Declarations --
//-----------------------------------------------------------------------

static const char rcsid[] = "$Id: UserExample.cc,v 1.11 1999/10/29 21:58:38 sexton Exp $";

//----------------
// Constructors --
//----------------

MinMod::MinMod( 
    const char* const theName, 
    const char* const theDescription )
    : AppModule( theName, theDescription )
{
}


//--------------
// Destructor --
//--------------

MinMod::~MinMod( )
{
}

//--------------
// Operations --
//--------------

AppResult MinMod::beginJob( AbsEvent* aJob )
{
    cout << name( ) << " begin Job" << endl;
    return AppResult::OK;
}

AppResult MinMod::beginRun( AbsEvent* aRun )
{
    cout << name( ) << " begin Run" << endl;
    return AppResult::OK;
}

AppResult MinMod::event( AbsEvent* anEvent )
{
    cout << name( ) << " event entry" << endl;

// For CDF users, this is an example of how to access event data in a user
// written module.  Note that a pointer to the event is passed to the event
// entry, and that entry returns the (optionally) modified event.
//
#ifdef USE_CDFEDM2
   EventRecord::ConstIterator iLRID( anEvent, "LRID_StorableBank") ;
   if (iLRID.is_valid())
   { 
      ConstHandle<LRID_StorableBank> h_LRID(iLRID) ;
      h_LRID->print();
   }
#else
    // Locate LRID in the record
    TRY_Record_Iter_Same iLRID( anEvent,"LRID" ) ;

    if ( iLRID.is_valid( ) )  // if we found one...
    {
       LRID_Bank aLRID( iLRID );  // Construct LRID obj. from iterator

       aLRID.print( );
    }
#endif
    cout << "Global run, trigNumber, and monteFlags: "
	 << gblEnv->runNumber()
	 << "   " << gblEnv->trigNumber()
	 << "   " << gblEnv->monteFlag() << endl;
    
    return AppResult::OK;
}

AppResult MinMod::other( AbsEvent* )
{
    cout << name( ) << " other" << endl;
    return AppResult::OK;
}

AppResult MinMod::endRun( AbsEvent* aRun )
{
    cout << name( ) << " end Run" << endl;
    return AppResult::OK;
}

AppResult MinMod::endJob( AbsEvent* aJob )
{
    cout << name( ) << " end Job" << endl;
    return AppResult::OK;
}

AppResult MinMod::abortJob( AbsEvent* aJob )
{
    cout << name( ) << " abort Job" << endl;
    return AppResult::OK;
}

AppModule*
MinMod::clone(const char* cloneName)
{
  return new MinMod(cloneName,"this module is a clone MinMod");
}

const char * 
MinMod::rcsId( ) const
{
   return rcsid;
}
